@@ -200,8 +200,15 @@ var DesktopGrid = class extends SignalManager.SignalManager{
     sizeEventBox() {
         this._eventBox.margin_top = this._marginTop;
         this._eventBox.margin_bottom = this._marginBottom;
-        this._eventBox.margin_start = this._marginLeft;
-        this._eventBox.margin_end = this._marginRight;
+        const leftToRight =
+            this._eventBox.get_direction() === Gtk.TextDirection.LTR;
+        if (leftToRight) {
+            this._eventBox.margin_start = this._marginLeft;
+            this._eventBox.margin_end = this._marginRight;
+        } else {
+            this._eventBox.margin_start = this._marginRight;
+            this._eventBox.margin_end = this._marginLeft;
+        }
     }
 
     setGridStatus() {
@@ -386,23 +393,14 @@ var DesktopGrid = class extends SignalManager.SignalManager{
         if (this._desktopManager.showDropPlace && (this._selectedList !== null)) {
             for (let [x, y] of this._selectedList) {
                 cr.rectangle(x + 0.5, y + 0.5, this._elementWidth, this._elementHeight);
-                Gdk.cairo_set_source_rgba(cr, new Gdk.RGBA({
-                    red: 1.0 - this._desktopManager.selectColor.red,
-                    green: 1.0 - this._desktopManager.selectColor.green,
-                    blue: 1.0 - this._desktopManager.selectColor.blue,
-                    alpha: 0.4,
-                })
-                );
+                let color = this._desktopManager.selectColor;
+                color.alpha = 0.4;
+                Gdk.cairo_set_source_rgba(cr, color);
                 cr.fill();
                 cr.setLineWidth(0.5);
                 cr.rectangle(x + 0.5, y + 0.5, this._elementWidth, this._elementHeight);
-                Gdk.cairo_set_source_rgba(cr, new Gdk.RGBA({
-                    red: 1.0 - this._desktopManager.selectColor.red,
-                    green: 1.0 - this._desktopManager.selectColor.green,
-                    blue: 1.0 - this._desktopManager.selectColor.blue,
-                    alpha: 1.0,
-                })
-                );
+                color.alpha = 1.0;
+                Gdk.cairo_set_source_rgba(cr, color);
                 cr.stroke();
             }
         }
